@@ -130,7 +130,7 @@ int main(int, char *argv[])
   try
   {
     Connection C(argv[1]);
-    C.SetClientEncoding("utf8");
+    C.SetClientEncoding("SQL_ASCII");
 
     // Perform (an instantiation of) the UpdateYears transactor we've defined
     // in the code above.  This is where the work gets done.
