@@ -40,13 +40,20 @@ int main(int argc, char *argv[])
     const string Table = ((argc >= 3) ? argv[2] : "pg_tables");
 
     LazyConnection C(argv[1]);
-    Transaction T(C, "test31");
 
-    Result R( T.Exec("SELECT * FROM " + Table) );
+    // Tell C we won't be needing it for a while (not true, but let's pretend)
+    C.Deactivate();
 
     vector<int> NullFields;		// Maps column to no. of null fields
     vector<bool> SortedUp, SortedDown;	// Does column appear to be sorted?
 
+    // Reactivate C (not really needed, but it sounds more polite)
+    C.Activate();
+
+    Transaction T(C, "test31");
+
+    Result R( T.Exec("SELECT * FROM " + Table) );
+
     InitVector(NullFields, R.Columns(), 0);
     InitVector(SortedUp, R.Columns(), true);
     InitVector(SortedDown, R.Columns(), true);
